==> wildfly-ee-dist-28.0.0.Final-src.zip: wildfly-28.0.0.Final-src/microprofile/fault-tolerance-smallrye/extension/src/main/java/org/wildfly/extension/microprofile/faulttolerance/MicroProfileFaultToleranceSchema.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2019, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.wildfly.extension.microprofile.faulttolerance;

import static org.jboss.as.controller.PersistentResourceXMLDescription.builder;

import org.jboss.as.controller.PersistentResourceXMLDescription;
import org.jboss.as.controller.PersistentSubsystemSchema;
import org.jboss.as.controller.SubsystemURN;
import org.jboss.as.controller.xml.VersionedNamespace;
import org.jboss.staxmapper.IntVersion;

/**
 * Enumeration of supported subsystem schemas.
 *
 * @author Radoslav Husar
 */
public enum MicroProfileFaultToleranceSchema implements PersistentSubsystemSchema<MicroProfileFaultToleranceSchema> {

    VERSION_1_0(1, 0), // WildFly 19-present
    ;
    public static final MicroProfileFaultToleranceSchema CURRENT = VERSION_1_0;

    private final VersionedNamespace<IntVersion, MicroProfileFaultToleranceSchema> namespace;

    MicroProfileFaultToleranceSchema(int major, int minor) {
        this.namespace = new SubsystemURN<>(MicroProfileFaultToleranceExtension.SUBSYSTEM_NAME, new IntVersion(major, minor));
    }

    @Override
    public VersionedNamespace<IntVersion, MicroProfileFaultToleranceSchema> getNamespace() {
        return this.namespace;
    }

    @Override
    public PersistentResourceXMLDescription getXMLDescription() {
        return builder(MicroProfileFaultToleranceResourceDefinition.PATH, this.namespace).build();
    }
}

==> wildfly-ee-dist-29.0.0.Final-src.zip: wildfly-29.0.0.Final-src/microprofile/fault-tolerance-smallrye/extension/src/main/java/org/wildfly/extension/microprofile/faulttolerance/MicroProfileFaultToleranceSchema.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2019, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.wildfly.extension.microprofile.faulttolerance;

import static org.jboss.as.controller.PersistentResourceXMLDescription.builder;

import org.jboss.as.controller.PersistentResourceXMLDescription;
import org.jboss.as.controller.PersistentSubsystemSchema;
import org.jboss.as.controller.SubsystemSchema;
import org.jboss.as.controller.xml.VersionedNamespace;
import org.jboss.staxmapper.IntVersion;

/**
 * Enumeration of supported subsystem schemas.
 *
 * @author Radoslav Husar
 */
public enum MicroProfileFaultToleranceSchema implements PersistentSubsystemSchema<MicroProfileFaultToleranceSchema> {

    VERSION_1_0(1, 0), // WildFly 19-present
    ;
    public static final MicroProfileFaultToleranceSchema CURRENT = VERSION_1_0;

    private final VersionedNamespace<IntVersion, MicroProfileFaultToleranceSchema> namespace;

    MicroProfileFaultToleranceSchema(int major, int minor) {
        this.namespace = SubsystemSchema.createSubsystemURN(MicroProfileFaultToleranceExtension.SUBSYSTEM_NAME, new IntVersion(major, minor));
    }

    @Override
    public VersionedNamespace<IntVersion, MicroProfileFaultToleranceSchema> getNamespace() {
        return this.namespace;
    }

    @Override
    public PersistentResourceXMLDescription getXMLDescription() {
        return builder(MicroProfileFaultToleranceResourceDefinition.PATH, this.namespace).build();
    }
}
